#!/bin/csh

# HEPiX 3.9.10
# Copyright (C) 2003-2005 CERN
# Author: KELEMEN Peter <Peter.Kelemen@cern.ch>

# $Id: csh.cshrc,v 1.25 2008/04/02 07:44:22 fuji Exp $

if ( $?_HPX_SEEN_HEP_CSH_CSHRC ) then
	exit
endif
set _HPX_SEEN_HEP_CSH_CSHRC=1

if ( ! $?HPX_INIT ) then
	if ( $?HPX_HOME_CORE ) then
		source $HPX_HOME_CORE/init.csh
	else
		source /etc/hepix/init.csh
	endif
endif

# NOTE(fuji): sh(1) derivatives source `pathtools' here, but we have to
# define aliases to emulated shell functions for csh(1).  See csh/CORE/init
# for explanation.
alias hpx_path_is_present	"$_HPX_SOURCE_CMD $HPX_HOME_CORE/hpx_path_is_present.csh "
alias hpx_path_remove		"$_HPX_SOURCE_CMD $HPX_HOME_CORE/hpx_path_remove.csh "
alias hpx_path_prepend		"$_HPX_SOURCE_CMD $HPX_HOME_CORE/hpx_path_prepend.csh "
alias hpx_path_prepend_unique	"$_HPX_SOURCE_CMD $HPX_HOME_CORE/hpx_path_prepend_unique.csh "
alias hpx_path_prepend_unless_present	"$_HPX_SOURCE_CMD $HPX_HOME_CORE/hpx_path_prepend_unless_present.csh "
alias hpx_path_append		"$_HPX_SOURCE_CMD $HPX_HOME_CORE/hpx_path_append.csh "
alias hpx_path_append_unique	"$_HPX_SOURCE_CMD $HPX_HOME_CORE/hpx_path_append_unique.csh "
alias hpx_path_append_unless_present	"$_HPX_SOURCE_CMD $HPX_HOME_CORE/hpx_path_append_unless_present.csh "

umask $HPX_UMASK

# Determine HEP group name.
set HPX_PREF_GROUP=$HPX_USER_HOME/preferred-group
set HPX_HEPGROUP=$HPX_NONE
if ( -r $HPX_PREF_GROUP) then
	set HPX_HEPGROUP=`$HPXB_CAT $HPX_PREF_GROUP`
else
	set HPX_HEPGROUP=`$HPXB_ID | $HPXB_SED -n 's/^[^ ]\{1,\}[^(]\{1,\}(\([^)]\{1,\}\).*$/\1/p'`
endif
if ( "x$HPX_HEPGROUP" == x ) then
	set HPX_HEPGROUP=$HPX_NONE
endif

# Export sanitized environment variables.
setenv GROUP $HPX_HEPGROUP
if ( ! $?HOST && $?HOSTNAME ) then
	setenv HOST $HOSTNAME
endif
if ( ! $?HOST ) then
	setenv HOST `$HPXB_HOSTNAME | $HPXB_SED 's/\..*//'`
endif
if ( ! $?OS ) then
	setenv OS `$HPXB_UNAME`
endif
setenv HPX_OS_MAJOR `$HPXB_UNAME -r | $HPXB_CUT -f1 -d.`
setenv HPX_OS_MINOR `$HPXB_UNAME -r | $HPXB_CUT -f2 -d.`
if ( $OS == SunOS && $HPX_OS_MAJOR >= 5 && $HPX_OS_MINOR >= 4 ) then
	setenv OS "Solaris"
endif
if ( ! $?BINTYPE ) then
	setenv BINTYPE $OS
endif
if ( ! $?SYSTYPE ) then
	setenv SYSTYPE sysV
endif
if ( ! $?MANPATH ) then
	setenv MANPATH "/usr/man:/usr/local/man"
endif

hpx_source $HPX_HOME_SITE/csh.cshrc

# Incorporate assembled entries into PATH.
if ( $HPX_ROOT == YES ) then
	set HPX_PATH=$ROOTPATH
else
	set HPX_PATH=$USERPATH
endif

# STEP 0. Append PATH to HPX_PATH and empty PATH, we're going
# to iterate over HPX_PATH and uniquely append to an (initially
# empty) PATH.

set HPX_PATH=${HPX_PATH}:${PATH}
setenv PATH ""

# STEP 1. Create a space-separated list from HPX_PATH using the shell's
# PATH<->path synchronization.
set _HPX_PATH_SAVE=$PATH
setenv PATH $HPX_PATH
set hpx_path=($path)
setenv PATH $_HPX_PATH_SAVE
unset _HPX_PATH_SAVE

# STEP 2. Emulate what hpx_path_append_unique() does in sh(1)-derivatives.
# NOTE(fuji): Let's try with our shiny pathtools implementation.
foreach HPX_DIR ($hpx_path)
## 	set c=1
## 	set found=0
## 	while ( ! $found && $c <= $#path )
## 		if ( $HPX_DIR == "$path[$c]" ) then
## 			set found=1
## 		endif
## 		@ c++
## 	end
## 	if ( ! found ) then
## 		set path=($path $HPX_DIR)
## 	endif
	eval `hpx_path_append_unless_present "$HPX_DIR"`
end
## unset c
## unset found

# STEP 3. Release outer level temporary variables, we're done.
unset HPX_DIR
unset hpx_path
unset HPX_PATH

# Environment is set up.
setenv SAVEPATH $PATH
setenv HEP_ENV $SHELL
setenv ENVIRONMENT BATCH
hpx_debug "environment set to BATCH"

# For sh(1) derivatives, the rest is done in rc, for interactive shells.
setenv HPX_TTY `$HPXB_TTY`
if ( $status != 0 ) then
	set HPX_TTY=""
endif
hpx_debug "HPX_TTY set to $HPX_TTY"
if ( "x$HPX_TTY" != x ) then
	setenv ENVIRONMENT INTERACTIVE
	hpx_debug "environment set to INTERACTIVE"

	set filec	# completion
	set ignoreeof	# Ctrl-D does not exit interactive shells
	set noclobber	# '>' does not overwrite
	set notify	# asynchronous background job completion notification
	set time=100	# automatic timing of processes taking up >100 CPU seconds

	set histfile=$HOME/.history.$HOST
	set history=1000
	set savehist=500

	switch ($HPX_SHELL)
		case csh:
			if ( $HPX_ROOT == YES ) then
				alias setprompt 'set prompt="${HOST}:${cwd} # "'
			else
				alias setprompt 'set prompt="${HOST}:${cwd} > "'
			endif
			setprompt
			alias cd 'chdir \!* && setprompt'
			breaksw
		case tcsh:
			set prompt='%S[%m]%s %~ %# '
			breaksw
	endsw
endif

alias rs	'set noglob; eval `resize -u`; unset noglob'
alias nman	$HPXB_NROFF' -man \!* | $PAGER'
alias pp	$HPXB_PS' auxww | '$HPXB_EGREP' '\''PID|\!*'\'' | '$HPXB_GREP' -v grep'
alias pwd	'echo $cdw'

# ---

hpx_source $HPX_HOME_HEP/${HPX_SHELL}rc

# vim: nowrap
# End of file.
