#!/bin/csh

# HEPiX 3.9.10
# Copyright (C) 2003-2005 CERN
# Author: KELEMEN Peter <Peter.Kelemen@cern.ch>

# $Id: csh.cshrc,v 1.24 2008/04/02 07:44:22 fuji Exp $


if ( $?_HPX_SEEN_SITE_CSH_CSHRC ) then
	exit
endif
set _HPX_SEEN_SITE_CSH_CSHRC=1

if ( ! $?HPX_INIT ) then
	if ( $?HPX_HOME_CORE ) then
		source $HPX_HOME_CORE/init.csh
	else
		source /etc/hepix/init.csh
	endif
endif

# Determine HEP cell.
set HPX_CELL=cern.ch

# Determine HEP group directory.  Defaults to AFS.
set HPX_HEPGROUP_DIR=/afs/$HPX_CELL/group/$HPX_HEPGROUP
if ( ! -d $HPX_HEPGROUP_DIR ) then
	set HPX_HEPGROUP_DIR=/u/$HPX_HEPGROUP/pub$HPX_HEPGROUP
	if ( ! -d $HPX_HEPGROUP_DIR ) then
		set HPX_HEPGROUP_DIR=""
	endif
endif

# Sanitize and set site-wide environment variables.
setenv GROUP_DIR $HPX_HEPGROUP_DIR
setenv CLUSTER_DIR $HPX_CLUSTER_HOME

setenv WWW_HOME "http://www.cern.ch"
setenv NNTPSERVER news.cern.ch

setenv EDITOR "pico -w"
setenv VISUAL "$EDITOR"
setenv PAGER less
setenv PRINT_CMD xprint

setenv YP NO
if ( -x $HPXB_DOMAINNAME ) then
	setenv DOMAINNAME `$HPXB_DOMAINNAME`
endif
if ( $?DOMAINNAME ) then
	if ( $DOMAINNAME != "(none)" ) then
		setenv YP YES
	endif
endif

setenv CERN /cern
setenv CERN_LEVEL pro
setenv CERN_ROOT $CERN/$CERN_LEVEL

setenv HPX_INITIALE `echo $HPX_USER | $HPXB_CUT -c1`
setenv CASTOR_HOME /castor/$HPX_CELL/user/$HPX_INITIALE/$HPX_USER
setenv HPSS_HOME /hpss/$HPX_CELL/user/$HPX_INITIALE/$HPX_USER
setenv HSM_HOME $HPSS_HOME

setenv INITIALISED YES

if ( -x $HPXB_MAILREG ) then
	$HPXB_MAILREG -env tcsh > /tmp/env$$
	hpx_source /tmp/env$$
	$HPXB_RM /tmp/env$$
endif

# NOTE(fuji): These are normally in the local namespace, but AFS
# group script maintainers tend to `setenv' these variables and
# then we have a namespace clash (no way to specify at dereference
# ($GROUPPATH) time which namespace to access.  See also ROOTPATH
# assignments.
# CT197070 Matthias Schrder <Matthias.Schroder@cern.ch>
if ( $?GROUP_DIR ) then
	setenv GROUPPATH $GROUP_DIR/bin
	setenv GROUPMANPATH $GROUP_DIR/man
else
	setenv GROUPPATH $HPX_NONE
	setenv GROUPMANPATH $HPX_NONE
endif

set HPX_LOCALPATH=/usr/local/bin:/usr/local/bin/X11
set HPX_SYSPATH=$HPX_NONE
set HPX_X11BIN=$HPX_NONE
set HPX_SYSMAN=/usr/man
if ( -r /etc/man.config ) then
	# TODO(fuji): Legacy implementation from old HEPiX codebase.
	set HPX_SYSMAN=`/bin/awk 'BEGIN{fi=1}/^MANPATH[\t ]/{if(fi==1){printf("%s",$2);fi=0}else{printf(":%s",$2)}}END{printf"\n"}' /etc/man.config`
endif

# OS-dependent PATH settings.
if ( $OS == Linux ) then
	setenv XFILESEARCHPATH "/usr/lib/X11/app-defaults/%N:/usr/local/lib/X11/app-defaults/%N"

	set HPX_SYSPATH="/usr/bin:/bin:/usr/bin/X11"
	set HPX_LOCALPATH="/usr/local/bin:/usr/local/bin/X11"
	setenv ROOTPATH $HPX_SYSPATH
else if ( $OS == Solaris ) then
	setenv OPENWINHOME /usr/openwin
	setenv MOTIFHOME /usr/dt
	setenv X11HOME $OPENWINHOME
	setenv LD_LIBRARY_PATH /opt/SUNWspro/lib:/usr/openwin/lib:/usr/dt/lib:/usr/local/lib
	setenv XFILESEARCHPATH ${OPENWINHOME}/lib/%T/%N%S:/usr/local/lib/X11/%T/%N%S

	set HPX_SYSPATH=/usr/sbin:/opt/SUNWspro/bin:/usr/ccs/bin:/usr/bin:${OPENWINHOME}/bin:${MOTIFHOME}/bin:/usr/ucb
	set HPX_SYSMAN=/opt/SUNWspro/man:/usr/man:/usr/openwin/man:/usr/dt/man
	set HPX_X11BIN=/usr/local/bin/X11
	setenv ROOTPATH /bin:/usr/bin:/usr/ucb:/etc:/usr/etc:${OPENWINHOME}/bin
else if ( $OS == SunOS ) then
	setenv OPENWINHOME /usr/openwin
	setenv MOTIFHOME /usr/motif12
	setenv X11HOME ${OPENWINHOME}
	setenv MYCHOICE newsmotif12	# legacy
	setenv LD_LIBRARY_PATH /opt/SUNWspro/lib:/usr/openwin/lib:/usr/motif12/usr/lib:/usr/local/lib
   	setenv XFILESEARCHPATH ${OPENWINHOME}/lib/%T/%N%S:/usr/local/lib/X11/%T/%N%S

	set HPX_SYSPATH=/usr/sbin:/opt/SUNWspro/bin:/usr/ccs/bin:/usr/bin:${OPENWINHOME}/bin:${MOTIFHOME}/usr/bin/X11:/usr/ucb
	set HPX_SYSMAN=/opt/SUNWspro/man:/usr/man:${OPENWINHOME}/man:${MOTIFHOME}/usr/man
	set HPX_X11BIN=/usr/local/bin/X11
	setenv ROOTPATH /bin:/usr/bin:/usr/ucb:/etc:/usr/etc:${OPENWINHOME}/bin
endif

hpx_source $HPX_SYSTEM_HOME/sys.conf.csh
hpx_source $HPX_CLUSTER_HOME/sys.conf.csh
hpx_source $GROUP_DIR/group_sys.conf.csh

hpx_source $HPX_SYSTEM_HOME/env.csh
hpx_source $HPX_CLUSTER_HOME/env.csh
hpx_source $GROUP_DIR/group_env.csh

if ( $?GROUPPATH ) then
	echo "$GROUPPATH" | $HPXB_GREP ' ' >/dev/null
	if ( $status == 0 ) then
		hpx_debug "GROUPPATH contains obsolete space separator, use colons."
		setenv GROUPPATH `echo "$GROUPPATH" | $HPXB_SED 's/ /:/g'`
	endif
endif
if ( $?USERPATH ) then
	echo "$USERPATH" | $HPXB_GREP ' ' >/dev/null
	if ( $status == 0 ) then
		hpx_debug "USERPATH contains obsolete space separator, use colons."
		setenv USERPATH `echo "$USERPATH" | $HPXB_SED 's/ /:/g'`
	endif
endif

setenv USERPATH ${HOME}/bin:${HOME}/scripts:/usr/sue/bin:${GROUPPATH}:${HPX_LOCALPATH}:${HPX_SYSPATH}:${HPX_X11BIN}:${CERN_ROOT}/bin
setenv MANPATH ${HOME}/man:/usr/sue/man:${GROUPMANPATH}:${HPX_SYSMAN}:/usr/local/man:${CERN}/man

unset HPX_LOCALPATH
unset HPX_SYSPATH
unset HPX_X11BIN
unset HPX_SYSMAN

# Fix up paths that might contain $HPX_NONEs.
setenv USERPATH `echo $USERPATH | $HPXB_SED 's/:\?'$HPX_NONE':\?/:/g;s/^://;s/:$//;s/:\{1,\}/:/g'`
setenv MANPATH `echo $MANPATH | $HPXB_SED 's/:\?'$HPX_NONE':\?/:/g;s/^://;s/:$//;s/:\{1,\}/:/g'`

# For sh(1) derivatives, the rest is done in rc, for interactive shells.
# ---
alias h		history
# The `ll' alias is provided by RedHat.
if ( $OS != "Linux" ) then
	alias ll	"$HPXB_LS -l "
endif
alias lf	"$HPXB_LS -CF "
alias terminal	'setenv TERM `'$HPXB_TSET' - \!*`'

hpx_source $HPX_SYSTEM_HOME/aliases.csh
hpx_source $HPX_CLUSTER_HOME/aliases.csh
hpx_source $GROUP_DIR/group_aliases.csh

setenv HPX_TTY `$HPXB_TTY`
if ( "x$HPX_TTY" != x ) then
	setenv ENVIRONMENT INTERACTIVE
endif
# ---

hpx_source $HPX_SYSTEM_HOME/csh.cshrc
hpx_source $HPX_CLUSTER_HOME/csh.cshrc
hpx_source $GROUP_DIR/group_csh.cshrc

# vim: nowrap
# End of file.
