#!/bin/csh

# HEPiX 3.9.10
# Copyright (C) 2003-2005 CERN
# Author: KELEMEN Peter <Peter.Kelemen@cern.ch>

# $Id: csh.login,v 1.27 2008/04/02 07:43:36 fuji Exp $

if ( $?_HPX_SEEN_SITE_CSH_LOGIN ) then
	exit
endif
set _HPX_SEEN_SITE_CSH_LOGIN=1

if ( ! $?HPX_INIT ) then
	if ( $?HPX_HOME_CORE ) then
		source $HPX_HOME_CORE/init.csh
	else
		source /etc/hepix/init.csh
	endif
endif

if ( "$GROUP" == $HPX_NONE ) then
	hpx_echo "W: HEPiX was unable to figure out your group name."
	hpx_echo "W: Please send mail to <Setup.Support@cern.ch>."
endif

if ( -r /etc/copyright ) then
	$HPXB_CAT /etc/copyright
endif
if ( -r $HPX_SYSTEM_HOME/motd ) then
	$HPBX_CAT $HPX_SYSTEM_HOME/motd
endif

if ( $?PASSWORD_EXPIRES ) then
	if ( $PASSWORD_EXPIRES <= 7 ) then
		hpx_echo "W: Your password will expire in $PASSWORD_EXPIRES days."
	endif
endif

if ( "x$HPX_AFS_HOME" != x ) then
	alias _hpx_afs_quota_check	"$_HPX_SOURCE_CMD $HPX_HOME_CORE/_hpx_afs_quota_check.csh "
	if ( -x /usr/afsws/bin/fs ) then
		set HPXB_FS=/usr/afsws/bin/fs
	endif
	if ( -x /usr/sue/bin/fs ) then
		set HPXB_FS=/usr/sue/bin/fs
	endif
	if ( -x /usr/bin/fs ) then
		set HPXB_FS=/usr/bin/fs
	endif
	if ( $?HPXB_FS ) then
		# Execute fs lq ~ command and extract numbers from output.
		# The shell could do the whitespace split but fs(1) is
		# altering output on quota-near-full conditions.
		# NOTE(fuji): csh/tcsh is uncapable of redirecting stderr only.
		set _HPX_LQ=`$HPXB_FS lq $HOME`

		# fs(1) would complain loudly of access violation if
		# logging in without a token.
		if ( $status == 0 ) then
			hpx_debug $_HPX_LQ
			set _HPX_LQ=`echo $_HPX_LQ | \
				$HPXB_SED -n '1s/^[^.]*\.[^ ]* [^0-9]*\([0-9]*\)[^0-9]*\([0-9]*\)[^0-9]*\([0-9]*\)%[^0-9]*\([0-9]*\)%.*$/\1 \2 \3 \4/p'`
			hpx_debug $_HPX_LQ
			_hpx_afs_quota_check $_HPX_LQ
		else
			hpx_echo "E: $HPXB_FS returned error, no tokens?"
		endif
		unset _HPX_LQ
	else
		hpx_echo "E: Unable to check AFS quota, no fs(1) binary?"
	endif
endif

# TODO(fuji): hpx_afs_uco_newuser()

### Terminal setting.
if ( -r /usr/share/terminfo ) then
      set _HPX_TIBASE=/usr/share/terminfo
else
      set _HPX_TIBASE=/usr/lib/terminfo
endif

if ( $?TERM ) then
	set _HPX_TERM="$TERM"
else
	set _HPX_TERM="(undef)"
endif
set _HPX_TTYPE=`echo "$_HPX_TERM" | $HPXB_CUT -c1`
set _HPX_TIPATH=$_HPX_TIBASE/$_HPX_TTYPE

if ( ! -r $_HPX_TIPATH/$_HPX_TERM ) then
      set _HPX_TERM=`echo $TERM | $HPXB_CUT -c1-5`
      if ( ! -r $_HPX_TIPATH/$_HPX_TERM ) then
      	set _HPX_TERM=`$HPXB_EXPR "$TERM" : '\([a-z0-9]*\).*'`
      	if ( ! -r $_HPX_TIPATH/$_HPX_TERM ) then
      		# Assume the worst case...
      		set _HPX_TERM=vt100
      		if ( -r /etc/termcap ) then
      			$HPXB_GREP '${TERM}|' /etc/termcap >/dev/null
      			if ( $status == 0 ) then
      				# ...but have a relief if possible.
      				set _HPX_TERM=$TERM
      			endif
      		endif
      	endif
      endif
endif
setenv TERM $_HPX_TERM

if ( "x$_HPX_TERM" != x && $_HPX_TERM != $TERM ) then
      hpx_echo "TERM $HPX_TERM changed to $TERM."
endif

unset _HPX_TIBASE
unset _HPX_TIPATH
unset _HPX_TTYPE
unset _HPX_TERM

# Personal temporary directory.
set HPX_TMPDIR=/tmp/$USER
if ( -d $HPX_TMPDIR ) then
	$HPXB_TEST -O $HPX_TMPDIR >/dev/null
	if ( $status == 0 ) then
		setenv TMPDIR $HPX_TMPDIR
	endif
endif
if ( ! $?TMPDIR ) then
	umask 0077
	$HPXB_MKDIR $HPX_TMPDIR >/dev/null
	if ( $status == 0 ) then
		setenv TMPDIR $HPX_TMPDIR
	endif
	umask $HPX_UMASK
	if ( $?TMPDIR ) then
		hpx_debug "Created $HPX_TMPDIR."
	endif
endif
if ( ! $?TMPDIR ) then
	unset HPX_TMPDIR
endif

hpx_source $HPX_SYSTEM_HOME/csh.login
hpx_source $HPX_CLUSTER_HOME/csh.login
hpx_source $GROUP_DIR/group_csh.login

hpx_source $HPX_SYSTEM_HOME/login.csh
hpx_source $HPX_CLUSTER_HOME/login.csh
hpx_source $GROUP_DIR/group_login.csh

hpx_source $HPX_SYSTEM_HOME/termset.csh
hpx_source $HPX_CLUSTER_HOME/termset.csh
hpx_source $GROUP_DIR/group_termset.csh

# Pull in ORACLE environment if necessary.
if ( -r $HPX_USER_HOME/oracle ) then
	set HPX_ORACLE=`$HPXB_CAT $HPX_USER_HOME/oracle`
	switch ($HPX_ORACLE)
		case 1:
		case yes:
		case Yes:
		case YES:
			hpx_source $HPX_SYSTEM_HOME/oracle_env.csh
			breaksw
	endsw
endif

# vim: nowrap
# End of file.
